@@ -1,13 +1,12 @@
 from .misc import *
 from .toolkit import *
-from .wrapper import TabularData
+from .api import TabularData
 
 
 __all__ = [
     "TabularData",
     "TabularDataset",
     "TimeSeriesConfig",
-    "TimeSeriesModifier",
     "TaskTypes",
     "task_type_type",
     "parse_task_type",
